@@ -1,8 +1,11 @@
+"""
+Activation functions used in neural networks
+"""
 from typing import Callable, Any
 
 import tensorflow.keras.backend as kb
-from tensorflow.keras.activations import get as keras_get
 from tensorflow.keras.activations import deserialize, serialize  # noqa
+from tensorflow.keras.activations import get as keras_get
 
 from megnet.utils.typing import OptStrOrCallable
 
@@ -37,5 +40,4 @@ def get(identifier: OptStrOrCallable = None) -> Callable[..., Any]:
     except ValueError:
         if isinstance(identifier, str):
             return deserialize(identifier, custom_objects=globals())
-        else:
-            raise ValueError('Could not interpret:',  identifier)
+    raise ValueError('Could not interpret:', identifier)
