@@ -2,3 +2,7 @@
 Featurizers used after the graph generation and before the graph convolution
 """
 from ._gaussian_expansion import GaussianExpansion
+
+__all__ = [
+    "GaussianExpansion"
+]
